@@ -2,6 +2,7 @@ import argparse
 import logging
 import os
 from typing import List, Optional, Text, Dict, Union, Any
+import asyncio
 
 from rasa.cli import SubParsersAction
 import rasa.shared.data
@@ -21,6 +22,7 @@ from rasa.shared.constants import (
     DEFAULT_MODELS_PATH,
     DEFAULT_DATA_PATH,
     DEFAULT_RESULTS_PATH,
+    DEFAULT_DOMAIN_PATH,
 )
 import rasa.shared.utils.validation as validation_utils
 import rasa.cli.utils
@@ -91,7 +93,7 @@ def _print_core_test_execution_info(args: argparse.Namespace) -> None:
         )
 
 
-def run_core_test(args: argparse.Namespace) -> None:
+async def run_core_test_async(args: argparse.Namespace) -> None:
     """Run core tests."""
     from rasa.model_testing import (
         test_core_models_in_directory,
@@ -125,11 +127,11 @@ def run_core_test(args: argparse.Namespace) -> None:
         )
 
         if args.evaluate_model_directory:
-            test_core_models_in_directory(
+            await test_core_models_in_directory(
                 args.model, stories, output, use_conversation_test_files=args.e2e
             )
         else:
-            test_core(
+            await test_core(
                 model=model_path,
                 stories=stories,
                 output=output,
@@ -138,7 +140,7 @@ def run_core_test(args: argparse.Namespace) -> None:
             )
 
     else:
-        test_core_models(
+        await test_core_models(
             args.model, stories, output, use_conversation_test_files=args.e2e
         )
 
@@ -154,7 +156,6 @@ async def run_nlu_test_async(
     percentages: List[int],
     runs: int,
     no_errors: bool,
-    domain_path: Text,
     all_args: Dict[Text, Any],
 ) -> None:
     """Runs NLU tests.
@@ -171,7 +172,6 @@ async def run_nlu_test_async(
                           or not.
         percentages: defines the exclusion percentage of the training data.
         runs: number of comparison runs to make.
-        domain_path: path to domain.
         no_errors: indicates if incorrect predictions should be written to a file
                    or not.
     """
@@ -183,9 +183,9 @@ async def run_nlu_test_async(
 
     data_path = rasa.cli.utils.get_validated_path(data_path, "nlu", DEFAULT_DATA_PATH)
     test_data_importer = TrainingDataImporter.load_from_dict(
-        training_data_paths=[data_path], domain_path=domain_path,
+        training_data_paths=[data_path], domain_path=DEFAULT_DOMAIN_PATH
     )
-    nlu_data = await test_data_importer.get_nlu_data()
+    nlu_data = test_data_importer.get_nlu_data()
 
     output = output_dir or DEFAULT_RESULTS_PATH
     all_args["errors"] = not no_errors
@@ -205,7 +205,7 @@ async def run_nlu_test_async(
         for file in config:
             try:
                 validation_utils.validate_yaml_schema(
-                    rasa.shared.utils.io.read_file(file), CONFIG_SCHEMA_FILE,
+                    rasa.shared.utils.io.read_file(file), CONFIG_SCHEMA_FILE
                 )
                 config_files.append(file)
             except YamlException:
@@ -225,7 +225,10 @@ async def run_nlu_test_async(
         config = rasa.cli.utils.get_validated_path(
             config, "config", DEFAULT_CONFIG_PATH
         )
-        perform_nlu_cross_validation(config, nlu_data, output, all_args)
+        config_importer = TrainingDataImporter.load_from_dict(config_path=config)
+
+        config_dict = config_importer.get_config()
+        await perform_nlu_cross_validation(config_dict, nlu_data, output, all_args)
     else:
         model_path = rasa.cli.utils.get_validated_path(
             models_path, "model", DEFAULT_MODELS_PATH
@@ -240,8 +243,7 @@ def run_nlu_test(args: argparse.Namespace) -> None:
     Args:
         args: the parsed CLI arguments for 'rasa test nlu'.
     """
-
-    rasa.utils.common.run_in_loop(
+    asyncio.run(
         run_nlu_test_async(
             args.config,
             args.nlu,
@@ -251,12 +253,20 @@ def run_nlu_test(args: argparse.Namespace) -> None:
             args.percentages,
             args.runs,
             args.no_errors,
-            args.domain,
             vars(args),
         )
     )
 
 
+def run_core_test(args: argparse.Namespace) -> None:
+    """Runs Core tests.
+
+    Args:
+        args: the parsed CLI arguments for 'rasa test core'.
+    """
+    asyncio.run(run_core_test_async(args))
+
+
 def test(args: argparse.Namespace) -> None:
     """Run end-to-end tests."""
     setattr(args, "e2e", True)
