@@ -38,7 +38,7 @@ from rasa.shared.core.constants import (
     ACTIVE_LOOP,
     ACTION_VALIDATE_SLOT_MAPPINGS,
     MAPPING_TYPE,
-    PREDEFINED_MAPPINGS,
+    SlotMappingType,
     LOOP_REJECTED,
 )
 from rasa.shared.core.domain import Domain
@@ -923,9 +923,9 @@ class ActionDefaultAskAffirmation(Action):
 
         intent_to_affirm = latest_message.intent.get(INTENT_NAME_KEY)
 
-        intent_ranking: List["IntentPrediction"] = latest_message.parse_data.get(
-            INTENT_RANKING_KEY
-        ) or []
+        intent_ranking: List["IntentPrediction"] = (
+            latest_message.parse_data.get(INTENT_RANKING_KEY) or []
+        )
         if (
             intent_to_affirm == DEFAULT_NLU_FALLBACK_INTENT_NAME
             and len(intent_ranking) > 1
@@ -1009,8 +1009,8 @@ class ActionExtractSlots(Action):
     def _verify_mapping_conditions(
         mapping: Dict[Text, Any], tracker: "DialogueStateTracker", slot_name: Text
     ) -> bool:
-        if mapping.get(MAPPING_CONDITIONS) and mapping.get(MAPPING_TYPE) != str(
-            SlotMapping.FROM_TRIGGER_INTENT
+        if mapping.get(MAPPING_CONDITIONS) and mapping[MAPPING_TYPE] != str(
+            SlotMappingType.FROM_TRIGGER_INTENT
         ):
             if not ActionExtractSlots._matches_mapping_conditions(
                 mapping, tracker, slot_name
@@ -1076,7 +1076,7 @@ class ActionExtractSlots(Action):
             return [], executed_custom_actions
 
         slot_events = await self._run_custom_action(
-            custom_action, output_channel, nlg, tracker, domain,
+            custom_action, output_channel, nlg, tracker, domain
         )
 
         executed_custom_actions.add(custom_action)
@@ -1129,7 +1129,7 @@ class ActionExtractSlots(Action):
     ) -> bool:
         from rasa.core.actions.forms import FormAction
 
-        if mapping.get("type") != str(SlotMapping.FROM_ENTITY):
+        if mapping[MAPPING_TYPE] != str(SlotMappingType.FROM_ENTITY):
             return False
 
         form_name = tracker.active_loop_name
@@ -1142,6 +1142,9 @@ class ActionExtractSlots(Action):
 
         form = FormAction(form_name, self._action_endpoint)
 
+        if slot_name not in form.required_slots(domain):
+            return False
+
         if form.entity_mapping_is_unique(mapping, domain):
             return False
 
@@ -1164,7 +1167,14 @@ class ActionExtractSlots(Action):
 
         for slot in user_slots:
             for mapping in slot.mappings:
-                if not SlotMapping.check_mapping_validity(slot.name, mapping, domain):
+                mapping_type = SlotMappingType(mapping.get(MAPPING_TYPE))
+
+                if not SlotMapping.check_mapping_validity(
+                    slot_name=slot.name,
+                    mapping_type=mapping_type,
+                    mapping=mapping,
+                    domain=domain,
+                ):
                     continue
 
                 intent_is_desired = SlotMapping.intent_is_desired(
@@ -1184,8 +1194,10 @@ class ActionExtractSlots(Action):
                 ):
                     continue
 
-                if mapping.get(MAPPING_TYPE) in PREDEFINED_MAPPINGS:
-                    value = extract_slot_value_from_predefined_mapping(mapping, tracker)
+                if mapping_type.is_predefined_type():
+                    value = extract_slot_value_from_predefined_mapping(
+                        mapping_type, mapping, tracker
+                    )
                 else:
                     value = None
 
@@ -1196,9 +1208,7 @@ class ActionExtractSlots(Action):
                     if tracker.get_slot(slot.name) != value:
                         slot_events.append(SlotSet(slot.name, value))
 
-                should_fill_custom_slot = mapping.get(MAPPING_TYPE) == str(
-                    SlotMapping.CUSTOM
-                )
+                should_fill_custom_slot = mapping_type == SlotMappingType.CUSTOM
 
                 if should_fill_custom_slot:
                     (
@@ -1222,23 +1232,26 @@ class ActionExtractSlots(Action):
 
 
 def extract_slot_value_from_predefined_mapping(
-    mapping: Dict[Text, Any], tracker: "DialogueStateTracker",
+    mapping_type: SlotMappingType,
+    mapping: Dict[Text, Any],
+    tracker: "DialogueStateTracker",
 ) -> List[Any]:
     """Extracts slot value if slot has an applicable predefined mapping."""
-    should_fill_entity_slot = mapping.get(MAPPING_TYPE) == str(
-        SlotMapping.FROM_ENTITY
-    ) and SlotMapping.entity_is_desired(mapping, tracker,)
+    should_fill_entity_slot = (
+        mapping_type == SlotMappingType.FROM_ENTITY
+        and SlotMapping.entity_is_desired(mapping, tracker)
+    )
 
-    should_fill_intent_slot = mapping.get(MAPPING_TYPE) == str(SlotMapping.FROM_INTENT)
+    should_fill_intent_slot = mapping_type == SlotMappingType.FROM_INTENT
 
-    should_fill_text_slot = mapping.get(MAPPING_TYPE) == str(SlotMapping.FROM_TEXT)
+    should_fill_text_slot = mapping_type == SlotMappingType.FROM_TEXT
 
     active_loops_in_mapping_conditions = [
         active_loop.get(ACTIVE_LOOP)
         for active_loop in mapping.get(MAPPING_CONDITIONS, [])
     ]
     should_fill_trigger_slot = (
-        mapping.get(MAPPING_TYPE) == str(SlotMapping.FROM_TRIGGER_INTENT)
+        mapping_type == SlotMappingType.FROM_TRIGGER_INTENT
         and tracker.active_loop_name not in active_loops_in_mapping_conditions
     )
 
