@@ -12,10 +12,7 @@ from typing import Text, ContextManager, Tuple, Union
 
 import rasa.utils.common
 import rasa.shared.utils.io
-from rasa.engine.storage.storage import (
-    ModelMetadata,
-    ModelStorage,
-)
+from rasa.engine.storage.storage import ModelMetadata, ModelStorage
 from rasa.engine.graph import GraphModelConfiguration
 from rasa.engine.storage.resource import Resource
 from rasa.exceptions import UnsupportedModelVersionError
@@ -65,10 +62,7 @@ class LocalModelStorage(ModelStorage):
 
             metadata = cls._load_metadata(temporary_directory)
 
-            return (
-                cls(storage_path),
-                metadata,
-            )
+            return (cls(storage_path), metadata)
 
     @classmethod
     def metadata_from_archive(
@@ -85,14 +79,14 @@ class LocalModelStorage(ModelStorage):
 
     @staticmethod
     def _extract_archive_to_directory(
-        model_archive_path: Union[Text, Path], temporary_directory: Path,
+        model_archive_path: Union[Text, Path], temporary_directory: Path
     ) -> None:
         with TarSafe.open(model_archive_path, mode="r:gz") as tar:
             tar.extractall(temporary_directory)
         LocalModelStorage._assert_not_rasa2_archive(temporary_directory)
 
     @staticmethod
-    def _assert_not_rasa2_archive(temporary_directory: Path,) -> None:
+    def _assert_not_rasa2_archive(temporary_directory: Path) -> None:
         fingerprint_file = Path(temporary_directory) / "fingerprint.json"
         if fingerprint_file.is_file():
             serialized_fingerprint = rasa.shared.utils.io.read_json_file(
@@ -107,9 +101,7 @@ class LocalModelStorage(ModelStorage):
         temporary_directory: Path, storage_path: Path
     ) -> None:
         for path in (temporary_directory / MODEL_ARCHIVE_COMPONENTS_DIR).glob("*"):
-            shutil.move(
-                str(path), str(storage_path),
-            )
+            shutil.move(str(path), str(storage_path))
 
     @staticmethod
     def _load_metadata(directory: Path) -> ModelMetadata:
@@ -183,7 +175,7 @@ class LocalModelStorage(ModelStorage):
         return model_metadata
 
     @staticmethod
-    def _persist_metadata(metadata: ModelMetadata, temporary_directory: Path,) -> None:
+    def _persist_metadata(metadata: ModelMetadata, temporary_directory: Path) -> None:
 
         rasa.shared.utils.io.dump_obj_as_json_to_file(
             temporary_directory / MODEL_ARCHIVE_METADATA_FILE, metadata.as_dict()
