@@ -1,10 +1,9 @@
 import pprint as pretty_print
 import typing
 from typing import Any, Dict, Optional, Text
+import asyncio
 
-from rasa.core.interpreter import RasaNLUInterpreter
-from rasa.shared.nlu.interpreter import NaturalLanguageInterpreter
-from rasa.shared.utils.cli import print_error, print_success
+from rasa.shared.utils.cli import print_success
 import rasa.core.agent
 import rasa.utils.common
 
@@ -21,7 +20,6 @@ def chat(
     model_path: Optional[Text] = None,
     endpoints: Optional[Text] = None,
     agent: Optional["Agent"] = None,
-    interpreter: Optional[NaturalLanguageInterpreter] = None,
 ) -> None:
     """Chat to the bot within a Jupyter notebook.
 
@@ -29,27 +27,9 @@ def chat(
         model_path: Path to a combined Rasa model.
         endpoints: Path to a yaml with the action server is custom actions are defined.
         agent: Rasa Core agent (used if no Rasa model given).
-        interpreter: Rasa NLU interpreter (used with Rasa Core agent if no
-                     Rasa model is given).
     """
-
     if model_path:
-
-        agent = rasa.core.agent.create_agent(model_path, endpoints)
-
-    elif agent is not None and interpreter is not None:
-        # HACK: this skips loading the interpreter and directly
-        # sets it afterwards
-        nlu_interpreter = RasaNLUInterpreter(
-            "skip this and use given interpreter", lazy_init=True
-        )
-        nlu_interpreter.interpreter = interpreter
-        agent.interpreter = interpreter
-    else:
-        print_error(
-            "You either have to define a model path or an agent and an interpreter."
-        )
-        return
+        agent = rasa.core.agent.load_agent(model_path=model_path, endpoints=endpoints)
 
     print("Your bot is ready to talk! Type your messages here or send '/stop'.")
     while True:
@@ -57,7 +37,7 @@ def chat(
         if message == "/stop":
             break
 
-        responses = rasa.utils.common.run_in_loop(agent.handle_text(message))
+        responses = asyncio.run(agent.handle_text(message))
         for response in responses:
             _display_bot_response(response)
 
