@@ -85,7 +85,7 @@ class TrackerWithCachedStates(DialogueStateTracker):
         return tracker
 
     def past_states_for_hashing(
-        self, domain: Domain, omit_unset_slots: bool = False,
+        self, domain: Domain, omit_unset_slots: bool = False
     ) -> Deque[FrozenState]:
         """Generates and caches the past states of this tracker based on the history.
 
@@ -96,29 +96,19 @@ class TrackerWithCachedStates(DialogueStateTracker):
         Returns:
             A list of states
         """
-        if domain != self.domain:
-            raise ValueError(
-                "TrackerWithCachedStates cannot be used with a domain "
-                "that is different from the one it was created with."
-            )
-        if omit_unset_slots:
-            # the tracker caches states with omit_unset_slots=False
-            # Retrieving them from cache with omit_unset_slots=True is not possible as
-            # this information is lost after a position in the event stream is turned
-            # into a state
+        # we need to make sure this is the same domain, otherwise things will
+        # go wrong. but really, the same tracker shouldn't be used across
+        # domains
+        assert domain == self.domain
+
+        # if don't have it cached, we use the domain to calculate the states
+        # from the events
+        states_for_hashing = self._states_for_hashing
+        if states_for_hashing is None:
             states = super().past_states(domain, omit_unset_slots=omit_unset_slots)
             states_for_hashing = deque(self.freeze_current_state(s) for s in states)
-        else:
-            # if don't have it cached, we use the domain to calculate the states
-            # from the events
-            # note: we ignore omit_unset_slots here as the cache was generated
-            # with the default value
-            states_for_hashing = self._states_for_hashing
-            if not states_for_hashing:
-                states = super().past_states(domain)
-                states_for_hashing = deque(self.freeze_current_state(s) for s in states)
 
-            self._states_for_hashing = states_for_hashing
+        self._states_for_hashing = states_for_hashing
 
         return states_for_hashing
 
@@ -203,6 +193,7 @@ class TrackerWithCachedStates(DialogueStateTracker):
         """Modify the state of the tracker according to an ``Event``."""
         # if `skip_states` is `True`, this function behaves exactly like the
         # normal update of the `DialogueStateTracker`
+
         if self._states_for_hashing is None and not skip_states:
             # rest of this function assumes we have the previous state
             # cached. let's make sure it is there.
@@ -227,12 +218,14 @@ class TrackerWithCachedStates(DialogueStateTracker):
 
 
 # define types
-TrackerLookupDict = Dict[Optional[Text], List[TrackerWithCachedStates]]
+TrackerLookupDict = Dict[Text, List[TrackerWithCachedStates]]
 
 TrackersTuple = Tuple[List[TrackerWithCachedStates], List[TrackerWithCachedStates]]
 
 
 class TrainingDataGenerator:
+    """Generates trackers from training data."""
+
     def __init__(
         self,
         story_graph: StoryGraph,
@@ -249,8 +242,8 @@ class TrainingDataGenerator:
         The different story parts can end and start with checkpoints
         and this generator will match start and end checkpoints to
         connect complete stories. Afterwards, duplicate stories will be
-        removed and the data is augmented (if augmentation is enabled)."""
-
+        removed and the data is augmented (if augmentation is enabled).
+        """
         self.story_graph = story_graph.with_cycles_removed()
         if debug_plots:
             self.story_graph.visualize("story_blocks_connections.html")
@@ -650,7 +643,10 @@ class TrainingDataGenerator:
                 # we concatenate the story block names of the blocks that
                 # contribute to the trackers events
                 if tracker.sender_id:
-                    if step.block_name not in tracker.sender_id.split(" > "):
+                    if (
+                        step.block_name
+                        and step.block_name not in tracker.sender_id.split(" > ")
+                    ):
                         new_sender = tracker.sender_id + " > " + step.block_name
                     else:
                         new_sender = tracker.sender_id
