@@ -9,6 +9,9 @@ from rasa.shared.importers.importer import TrainingDataImporter
 from rasa.shared.importers.autoconfig import TrainingType
 from rasa.shared.nlu.training_data.training_data import TrainingData
 from rasa.shared.core.domain import InvalidDomain, Domain
+from rasa.shared.core.training_data.story_reader.yaml_story_reader import (
+    YAMLStoryReader,
+)
 import rasa.shared.utils.io
 
 logger = logging.getLogger(__name__)
@@ -31,44 +34,35 @@ class RasaFileImporter(TrainingDataImporter):
             training_data_paths, rasa.shared.data.is_nlu_file
         )
         self._story_files = rasa.shared.data.get_data_files(
-            training_data_paths, rasa.shared.data.is_story_file
+            training_data_paths, YAMLStoryReader.is_stories_file
         )
         self._conversation_test_files = rasa.shared.data.get_data_files(
-            training_data_paths, rasa.shared.data.is_test_stories_file
+            training_data_paths, YAMLStoryReader.is_test_stories_file
         )
 
         self.config = autoconfig.get_configuration(config_file, training_type)
 
-    async def get_config(self) -> Dict:
+    def get_config(self) -> Dict:
         """Retrieves model config (see parent class for full docstring)."""
         return self.config
 
-    async def get_stories(
-        self,
-        template_variables: Optional[Dict] = None,
-        use_e2e: bool = False,
-        exclusion_percentage: Optional[int] = None,
-    ) -> StoryGraph:
+    def get_stories(self, exclusion_percentage: Optional[int] = None) -> StoryGraph:
         """Retrieves training stories / rules (see parent class for full docstring)."""
-        return await utils.story_graph_from_paths(
-            self._story_files,
-            await self.get_domain(),
-            template_variables,
-            use_e2e,
-            exclusion_percentage,
+        return utils.story_graph_from_paths(
+            self._story_files, self.get_domain(), exclusion_percentage
         )
 
-    async def get_conversation_tests(self) -> StoryGraph:
+    def get_conversation_tests(self) -> StoryGraph:
         """Retrieves conversation test stories (see parent class for full docstring)."""
-        return await utils.story_graph_from_paths(
-            self._conversation_test_files, await self.get_domain(), use_e2e=True,
+        return utils.story_graph_from_paths(
+            self._conversation_test_files, self.get_domain()
         )
 
-    async def get_nlu_data(self, language: Optional[Text] = "en") -> TrainingData:
+    def get_nlu_data(self, language: Optional[Text] = "en") -> TrainingData:
         """Retrieves NLU training data (see parent class for full docstring)."""
         return utils.training_data_from_paths(self._nlu_files, language)
 
-    async def get_domain(self) -> Domain:
+    def get_domain(self) -> Domain:
         """Retrieves model domain (see parent class for full docstring)."""
         domain = Domain.empty()
 
